mod config;

use config::Config;

fn main() {
    // Load config
    let config = match Config::load() {
        Ok(cfg) => cfg,
        Err(e) => {
            eprintln!("Failed to load config: {e}");
            std::process::exit(1);
        }
    };

    // Weather
    let (temp, conditions, high, low, forecast) = get_weather(&config);
    println!("Weather for today:");
    println!(" - Temperature: {temp}");
    println!(" - Conditions: {conditions}");
    println!(" - High: {high}, Low: {low}");
    println!(" - Forecast: {forecast}");

    // Pollen count
    let pollen = get_pollen_count(&config);
    println!("\nPollen count: {pollen}");

    // Calendar events
    println!("\nUpcoming calendar events:");
    let events = get_calendar_events(&config, config.calendar_event_count);
    for (i, event) in events.iter().enumerate() {
        println!("{}. {}", i + 1, event);
    }

    // Shopify inbound packages
    println!("\nInbound Shopify packages:");
    let packages = get_shopify_packages(&config);
    for (i, pkg) in packages.iter().enumerate() {
        println!("{}. {}", i + 1, pkg);
    }
}

// Placeholder stubs, replace with actual API calls later
fn get_weather(_config: &Config) -> (String, String, String, String, String) {
    // TODO: Call weather API
    (
        "72°F".to_string(),
        "Partly cloudy".to_string(),
        "78°F".to_string(),
        "65°F".to_string(),
        "Mostly sunny, light breeze".to_string(),
    )
}

fn get_pollen_count(_config: &Config) -> String {
    // TODO: Call pollen count API
    "Medium (Tree: 5, Grass: 2, Weed: 1)".to_string()
}

fn get_calendar_events(_config: &Config, n: usize) -> Vec<String> {
    // TODO: Call calendar API
    vec![
        "Team meeting at 10:00 AM".to_string(),
        "Lunch with Alex at 12:30 PM".to_string(),
        "Dentist appointment at 3:00 PM".to_string(),
    ]
    .into_iter()
    .take(n)
    .collect()
}

fn get_shopify_packages(_config: &Config) -> Vec<String> {
    // TODO: Call Shopify API
    vec![
        "Order #1234: Shipped - Arriving May 13".to_string(),
        "Order #5678: In transit - Arriving May 15".to_string(),
    ]
}
